/* network-com.c: functions for managing communication.

    Copyright (C) 2001-2099, Rajkumar Buyya (rajkumar@buyya.com)!

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details @ www.gnu.org
*/

#include "header.h"
void skip_newline_char( char * buff );
void SkipNewlineSend(int client_socket, char *buff );
void MakeLookupFileName( char *pdbfile, char *lookupfile );

int readline( int dev_handle, char *buff, int len )
{
   char temp[2];
   int i = 0, res;

   while( (res = read( dev_handle, temp, 1 )) > 0 ) 
   {
      if( temp[0] == '\n' || i == len-1 )
			break;
      buff[i++] = temp[0];
   }
   buff[i] = '\0';
	return res;
} 

int writeline( int dev_handle, char *buff )
{
   if(  write( dev_handle, buff, strlen(buff) ) < 0 )
		return -1;
   if( write( dev_handle, "\n", 1) < 0 )
		return -1;
	return 1;
} 

/* CreateSocketAddress: It creates a socket address using
   host address which can be in the form of name or IP address.
   That is, argument "host" can be like "130.194.64.39" or "hathor.cs.monash.edu.au"
*/

int CreateSocketAddress(struct sockaddr_in *sockaddrPtr, char *host, int port)
    /* *sockaddrPtr;     Socket address 
       *host;           Host.  NULL implies INADDR_ANY 
        port;           Port number */
{
    struct hostent *hostent;            /* Host database entry */
    struct in_addr addr;                /* For 64/32 bit madness */

    (void) memset((void *) sockaddrPtr, '\0', sizeof(struct sockaddr_in));
    sockaddrPtr->sin_family = AF_INET;
    sockaddrPtr->sin_port = htons((unsigned short) (port & 0xFFFF));
    if (host == NULL) {
        addr.s_addr = INADDR_ANY;
    } else {
        addr.s_addr = inet_addr(host);
        if (addr.s_addr == -1) {
            hostent = gethostbyname(host);
            if (hostent != NULL) {
                memcpy((void *) &addr,
                        (void *) hostent->h_addr_list[0],
                        (size_t) hostent->h_length);
            } else {
#ifdef  EHOSTUNREACH
                errno = EHOSTUNREACH;
#else
#ifdef ENXIO
                errno = ENXIO;
#endif
#endif
                return 0;       /* error */
            }
        }
    }
        
    /*
     * NOTE: On 64 bit machines the assignment below is rumored to not
     * do the right thing. Please report errors related to this if you
     * observe incorrect behavior on 64 bit machines such as DEC Alphas.
     * Should we modify this code to do an explicit memcpy?
     */

    sockaddrPtr->sin_addr.s_addr = addr.s_addr;
    return 1;   /* Success. */
}

int FileCopy( int srcHandle, int dstHandle)
{
	char buff[BUFFSIZE];
	int nread;

	while(1)
	{
		nread = read( srcHandle, buff, BUFFSIZE );
		write( dstHandle, buff, nread ); 
		if( nread < BUFFSIZE )
			break;
	}
	return 1;
}
